/*
 * Copyright (C) 2013  INRIA.
 *
 * This file is subject to the terms and conditions of the GNU Lesser
 * General Public License v2.1. See the file LICENSE in the top level
 * directory for more details.
 */

/**
 * @defgroup    net_sixlowpan 6LoWPAN
 * @ingroup     net
 * @brief       6LoWPAN module implements (parts of) the 6LoWPAN adaption layer
 *              for IPv6 over Low Power Wireless Personal Area Networks
 *              (6LoWPANs)
 *
 * @see     <a href="http://tools.ietf.org/html/rfc4919">
 *              RFC 4919 - IPv6 over Low-Power Wireless Personal Area
 *                  Networks (6LoWPANs): Overview, Assumptions, Problem
 *                  Statement, and Goals
 *          </a>
 * @see     <a href="http://tools.ietf.org/html/rfc4944">
 *              RFC 4944 - Transmission of IPv6 Packets over
 *                  IEEE 802.15.4 Networks
 *          </a>
 * @see     <a href="http://tools.ietf.org/html/rfc6282">
 *              RFC 6282 - Compression Format for IPv6 Datagrams over
 *                  IEEE 802.15.4-Based Networks
 *          </a>
 * @see     <a href="http://tools.ietf.org/html/rfc6775">
 *              RFC 6775 - Neighbor Discovery Optimization for IPv6
 *              over Low-Power Wireless Personal Area Networks
 *              (6LoWPANs)
 *          </a>
 *
 *
 * @{
 * @file        sixlowpan.h
 * @brief       6lowpan link layer and lowpan functions
 *
 * @author      Martine Lenders <mlenders@inf.fu-berlin.de>
 */
#ifndef SIXLOWPAN_H
#define SIXLOWPAN_H

#include "sixlowpan/error.h"
#include "sixlowpan/types.h"
#include "sixlowpan/lowpan.h"
#include "sixlowpan/mac.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifdef __cplusplus
}
#endif

#endif /* SIXLOWPAN_H */
/** @} */
